@@ -99,7 +99,7 @@ void QpStackReg::Unlock()
 }
 
 
-#ifdef SUNWSPRO42
+#if defined(__SUNPRO_CC) && (__SUNPRO_CC <= 0x420)
 reg_item QpStackReg::Find(void *addr)
 #else
 QpStackReg::reg_item QpStackReg::Find(void *addr)
@@ -219,10 +219,14 @@ void QpSignal::Exit()
 		// the signal was received by signal thread,
 		// we can not do _exit() and then continue with
 		// the read and exit in the loop, so we do exit() and _exit() here
+		async_signal_handler(ASYNC_THR_EXIT);
+		return;
+#if 0
 #ifdef LINUX
 		exit(1); /* Linux has some thread cleaning on on_exit */
 #endif
 	 	_exit(1);
+#endif
 	}
 	async_signal_handler(ASYNC_THR_EXIT);
 	_exit(0);
@@ -402,6 +406,7 @@ void QpSignal::InstallHandler(int sig, SIG_HANDLER sh)
 	if (sig < 1 || sig > NSIG)
 		throw QpErrorException(QP_ERROR_ARG, "InstallHandler");
 	sa_act = sa_old = NULL;
+	func = NULL;
 	switch (sh) {
 	    case HANDLER_WITHORIG:
 	    case HANDLER:
@@ -433,7 +438,7 @@ void QpSignal::InstallHandler(int sig, SIG_HANDLER sh)
 		throw QpErrorException(QP_ERROR_ARG, "InstallHandler");
 	}
 	s_handler[sig] = sh;
-	if (!sa_act) {
+	if (func) {
 		sa.sa_handler = func;
 		sigfillset(&sa.sa_mask);
 		sa.sa_flags = SA_RESTART;
