@@ -11,24 +11,6 @@
 #include <fcntl.h>
 #include <qpthr/qp.h>
 
-void reltime_to_abs(const struct timespec *ts_rel, struct timespec *ts_abs)
-{
-	struct timeval tv;
-	
-	QPERR_ERRNO(gettimeofday(&tv, NULL));
-	ts_abs->tv_sec = tv.tv_sec + ts_rel->tv_sec;
-	ts_abs->tv_nsec = tv.tv_usec * 1000 + ts_rel->tv_nsec;
-	if (ts_abs->tv_nsec >= 1000000000) {
-		ts_abs->tv_sec += ts_abs->tv_nsec / 1000000000;
-		ts_abs->tv_nsec %= 1000000000;
-	}
-}
-
-void msectime_to_ts(unsigned int msec, struct timespec *ts_rel)
-{
-	ts_rel->tv_sec = msec / 1000;
-	ts_rel->tv_nsec = (msec % 1000) * 1000000;
-}
 
 bool QpCondBase::Wait(const struct timespec *ts, bool throw_ex)
 {
@@ -122,7 +104,7 @@ bool QpAsyncSafeSem::TryLock()
 	if (retval < 0 && read_errno == EAGAIN)
 		return false;
 	__QPERR(read_errno, read);
-	return false;
+//	return false;
 #else
 	/*
 	 * this implementation have one major problem - 
@@ -282,7 +264,7 @@ void QpMutex::Unlock()
 
 bool QpMutex::TryLock()
 { 
-	int retval = 0;
+	int retval;
 
 	retval = pthread_mutex_trylock(&m_mutex);
 	if (retval < 0 && retval != EBUSY) {
@@ -316,7 +298,7 @@ QpMutexCond::QpMutexCond(QpMutex& m, const char *name):
 
 bool QpMutexCond::WaitAbs(const struct timespec *ts, bool throw_ex)
 {
-	int retval = 0;
+	int retval;
 	
 	if (ts)
 		retval = pthread_cond_timedwait(&c_cond, &c_mutex->m_mutex, ts);
